@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2012 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -238,7 +238,7 @@ my %assert_payload = (
                 warp        => {
                     follow  => { 'type' => '?type', },
                     'rules' => [
-                        '$type eq "hash"' =>
+                        '$type eq "hash" or $type eq "list"' =>
                           { level => 'normal', },
                     ]
                 }
@@ -273,12 +273,11 @@ my %assert_payload = (
                 value_type => 'enum',
                 level      => 'hidden',
                 experience => 'advanced',
-                description =>
-'When stored, the value will be converted to uppercase (uc) or lowercase (lc).',
+                description => 'Convert value or index to uppercase (uc) or lowercase (lc).',
                 warp => {
                     follow  => { 't' => '?type' },
                     'rules' => [
-                        '$t eq "leaf"' => {
+                        '$t eq "leaf" or $t eq "hash"' => {
                             choice => [qw/uc lc/],
                             level  => 'normal',
                         }
@@ -292,20 +291,26 @@ my %assert_payload = (
                 level      => 'hidden',
                 experience => 'advanced',
                 description =>
-'Perl regular expression to assert the validity of the value.',
+                    'Perl regular expression to assert the validity of the value. To check the '
+                    . q!whole value, use C<^> and C<$>. For instance C<^foo|bar$> will allow !
+                    . q!C<foo> or C<bar> but not C<foobar>. To be case insentive, !
+                    . q!use the C<(?i)> extended pattern. For instance, the regexp !
+                    . q!C<^(?i)foo|bar$> will also allow the values !
+                    . q!C<Foo> and C<Bar>.!,
                 @warp_in_uniline_or_string,
             },
 
             'assert' => {
                 %assert_payload,
                 description =>
-                  'Raise an error if the test code snippet does returns false',
+                  'Raise an error if the test code snippet does returns false. Note this snippet will '
+                  . 'also be run on undefined value, which may not be what you want.',
             },
 
             'warn_unless' => {
                 %assert_payload,
                 description =>
-                  'Warn user if the tes code snippet does returns false',
+                  'Warn user if the code snippet returns false',
             },
 
             'warn_if_match' => {
@@ -326,7 +331,7 @@ my %assert_payload = (
                 level      => 'hidden',
                 experience => 'advanced',
                 description =>
-'Unconditionaly issue a warning with this string when this parameter is used. This should be used mostly with "accept"',
+'Unconditionally issue a warning with this string when this parameter is used. This should be used mostly with "accept"',
                 warp => {
                     follow  => { t              => '?type' },
                     'rules' => [ '$t eq "leaf"' => { level => 'normal', }, ]
